import { x as jsxs, w as jsx, D as Body, bH as PriceDisplay, B as Box, k as useTranslation, aA as Drawer, aP as MenuItem, aF as Fragment, aB as Divider, J as tokenValueFormat, h as formatZeroAmount, c4 as FooterLogo } from './index-8eE-4nTx.js';

const feesBreakdownContentStyles = {
    display: 'flex',
    flexDirection: 'column',
    height: '100%',
    padding: '16px 16px 0 16px',
};
const feeItemContainerStyles = {
    display: 'flex',
    flexDirection: 'column',
    gap: '10px',
    height: '100%',
};
const feeItemStyles = { display: 'flex', width: '100%' };
const feeItemLabelStyles = (boldLabel) => ({
    width: '65%',
    color: boldLabel ? 'base.color.text.body.primary' : 'base.color.text.body.secondary',
});
const feeItemPriceDisplayStyles = {
    width: '35%',
};
const feeItemLoadingStyles = {
    display: 'flex',
    flexDirection: 'column',
    rowGap: 'base.spacing.x2',
};

function FeeItem({ boldLabel, label, amount, fiatAmount, tokenSymbol, prefix = '', }) {
    const key = label.toLowerCase().replace(' ', '-');
    return (jsxs(Box, { sx: feeItemStyles, testId: `fee-item-${key}`, children: [jsx(Body, { sx: feeItemLabelStyles(boldLabel), children: label }), jsx(PriceDisplay, { testId: key, sx: feeItemPriceDisplayStyles, price: `${prefix}${tokenSymbol} ${amount}`, fiatAmount: fiatAmount })] }));
}

function FeesBreakdown({ fees, children, visible, onCloseDrawer, totalFiatAmount, totalAmount, tokenSymbol, loading = false, }) {
    const { t } = useTranslation();
    return (jsxs(Drawer, { headerBarTitle: t('drawers.feesBreakdown.heading'), size: "threeQuarter", onCloseDrawer: onCloseDrawer, visible: visible, children: [jsx(Drawer.Target, { children: children }), jsxs(Drawer.Content, { testId: "fees-breakdown-content", sx: feesBreakdownContentStyles, children: [jsxs(Box, { sx: feeItemContainerStyles, children: [loading && (jsxs(Box, { sx: feeItemLoadingStyles, children: [jsx(MenuItem, { shimmer: true, emphasized: true, testId: "balance-item-shimmer--1" }), jsx(MenuItem, { shimmer: true, emphasized: true, testId: "balance-item-shimmer--2" })] })), !loading && fees.map(({ label, amount, fiatAmount, prefix, token, }) => (jsx(FeeItem, { label: label, amount: amount, fiatAmount: fiatAmount, tokenSymbol: token.symbol ?? tokenSymbol, prefix: prefix }, label))), totalAmount && (jsxs(Fragment, { children: [jsx(Divider, { size: "xSmall" }), jsx(FeeItem, { label: t('drawers.feesBreakdown.total'), amount: tokenValueFormat(totalAmount), fiatAmount: totalFiatAmount
                                            ? `≈ ${t('drawers.feesBreakdown.fees.fiatPricePrefix')}${totalFiatAmount}`
                                            : formatZeroAmount('0'), tokenSymbol: tokenSymbol, boldLabel: true }, t('drawers.feesBreakdown.total'))] }))] }), jsx(FooterLogo, {})] })] }));
}

export { FeesBreakdown as F };
